summaryrefslogtreecommitdiff
path: root/libcuda
diff options
context:
space:
mode:
authorInderpreet Singh <[email protected]>2011-08-18 16:16:18 -0800
committerAndrew Boktor <[email protected]>2014-08-14 13:18:22 -0700
commit75cac88e2131564d79f0407c2d86d0429a1e2dba (patch)
tree8479e2d32f23baa9119148c834172a2ad90f3347 /libcuda
parent4944711704b7b0e3a43517471aa568e73998a861 (diff)
Assigned debug level 3 to stream manager output.
[git-p4: depot-paths = "//depot/gpgpu_sim_research/fermi/distribution/": change = 10013]
Diffstat (limited to 'libcuda')
-rw-r--r--libcuda/cuda_runtime_api.cc6
1 files changed, 4 insertions, 2 deletions
diff --git a/libcuda/cuda_runtime_api.cc b/libcuda/cuda_runtime_api.cc
index 101fe8c..8bb0e01 100644
--- a/libcuda/cuda_runtime_api.cc
+++ b/libcuda/cuda_runtime_api.cc
@@ -415,7 +415,8 @@ __host__ cudaError_t CUDARTAPI cudaMalloc(void **devPtr, size_t size)
{
CUctx_st* context = GPGPUSim_Context();
*devPtr = context->get_device()->get_gpgpu()->gpu_malloc(size);
- printf("GPGPU-Sim PTX: cudaMallocing %zu bytes starting at 0x%llx..\n",size, (unsigned long long) *devPtr);
+ if(g_debug_execution >= 3)
+ printf("GPGPU-Sim PTX: cudaMallocing %zu bytes starting at 0x%llx..\n",size, (unsigned long long) *devPtr);
if ( *devPtr ) {
return g_last_cudaError = cudaSuccess;
} else {
@@ -495,7 +496,8 @@ __host__ cudaError_t CUDARTAPI cudaMemcpy(void *dst, const void *src, size_t cou
{
//CUctx_st *context = GPGPUSim_Context();
//gpgpu_t *gpu = context->get_device()->get_gpgpu();
- printf("GPGPU-Sim PTX: cudaMemcpy(): devPtr = %p\n", dst);
+ if(g_debug_execution >= 3)
+ printf("GPGPU-Sim PTX: cudaMemcpy(): devPtr = %p\n", dst);
if( kind == cudaMemcpyHostToDevice )
g_stream_manager->push( stream_operation(src,(size_t)dst,count,0) );
else if( kind == cudaMemcpyDeviceToHost )